@@ -5,7 +5,7 @@ use warnings;
 use Socket;
 use Carp;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 =head1 NAME
 
@@ -55,7 +55,13 @@ By default, the server traps a few signals:
 
 =item HUP
 
-When you C<kill -HUP> the server, it does its best to rexec itself.
+When you C<kill -HUP> the server, it does its best to rexec
+itself.  Please note that in order to provide restart-on-SIGHUP,
+HTTP::Server::Simple sets a SIGHUP handler during initialisation. If
+your request handling code forks you need to make sure you reset this
+or unexpected things will happen if somebody sends a HUP to all running
+processes spawned by your app (e.g. by "kill -HUP <script>")
+
 
 =item PIPE
 
@@ -181,6 +187,9 @@ sub run {
 
     local $SIG{CHLD} = 'IGNORE';    # reap child processes
     local $SIG{HUP} = sub {
+
+        # XXX TODO: Autrijus says this code was incorrect when he wrote
+        # it and we should move to the sample code from perldoc perlipc
         close HTTPDaemon;
 
         # and then, on systems implementing fork(), we make sure
@@ -197,7 +206,7 @@ sub run {
 
         # do the exec. if $0 is not executable, try running it with $^X.
         exec {$0}( ( ( -x $0 ) ? () : ($^X) ), $0, @ARGV );
-    };
+    } if exists $SIG{'HUP'};
 
     # $pkg is generated anew for each invocation to "run"
     # Just so we can use different net_server() implementations
